@@ -68,7 +68,7 @@ function main (cxt) {
         if (wordLink) {
            this.pos.push(ast.callword(wordLink.index));
         } else {
-            console.log('word: ' + w + ' is not defined');
+            cxt.log('word: ' + w + ' is not defined');
             throw new Error;
         }
     }, cxt, { immediate: true });
@@ -184,8 +184,8 @@ function main (cxt) {
         });
 
         this.label++;
-        // console.log(jsof.s(this.ast, {ansi: true}));
-        // console.log(generate(this.ast));
+        // cxt.log(jsof.s(this.ast, {ansi: true}));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
     // def('if', function () {
@@ -219,8 +219,8 @@ function main (cxt) {
     def('then', function () {
         this.pos = this.cfs.pop();
         this.orig.pop();
-        // console.log(jsof.s(this.ast, {ansi: true}));
-        // console.log(generate(this.ast));
+        // cxt.log(jsof.s(this.ast, {ansi: true}));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -276,7 +276,7 @@ function main (cxt) {
                 body: this.pos
             }
         });
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -317,7 +317,7 @@ function main (cxt) {
             }
         });
         this.label++;
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -335,7 +335,7 @@ function main (cxt) {
     def('until', function () {
         this.pos = this.cfs.pop();
         this.pos[this.pos.length - 1].body.test = ast.notdpop();
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -392,7 +392,7 @@ function main (cxt) {
         });
 
         this.label++;
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 // 6.2.0700 AGAIN (CORE EXT)
@@ -410,7 +410,7 @@ function main (cxt) {
 
     def('again', function () {
         this.pos = this.cfs.pop();
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -440,7 +440,7 @@ function main (cxt) {
         this.pos = this.cfs.pop();
         var last = this.pos[this.pos.length - 1];
         last.label.name = 'L' + this.orig.pop();
-        // console.log(generate(this.ast));
+        // cxt.log(generate(this.ast));
     }, cxt, { immediate: true });
 
 
@@ -506,7 +506,7 @@ function main (cxt) {
         if (wordLink) {
             this.pos.push(ast.dpush(wordLink.index));
         } else {
-            console.log('word: ' + w + ' is not defined');
+            cxt.log('word: ' + w + ' is not defined');
             throw new Error;
         }
     }, cxt, { immediate: true });
