@@ -12,7 +12,6 @@ function fix (fn, cxt) {
         ast = fn;
     } else {
         ast = parse('fn = ' + fn.toString());
-        // console.log(JSON.stringify(ast, null, 4));
     }
 
     replace(ast, {
@@ -51,7 +50,7 @@ function fix (fn, cxt) {
 
         }
     });
-    if (changes || typeof fn === 'object') {
+    if (changes || typeof fn === 'object' || typeof fn === 'string') {
         eval(generate(ast));
     }
     return fn;
