@@ -5,11 +5,13 @@ var word = require('./word'),
     // estraverse = require('estraverse'),
     colors = require('colors/safe');
 
-// var Syntax = estraverse.Syntax;
-
 function interpret (str, done) {
     var w, wordLink, num, lines;
 
+    if (typeof str === 'string') {
+        str = new Buffer(str, 'ascii');
+    }
+
     this.io.buf = str;
     this.io.ptr = 0;
     this.io.last = str.length - 1;
@@ -33,9 +35,9 @@ function interpret (str, done) {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
                     lines = this.io.buf.slice(0, this.io.ptr).split('\n');
-                    console.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
-                    console.log('word: ' + w + ' is not defined');
-                    console.log(lines.pop());
+                    this.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
+                    this.log('word: ' + w + ' is not defined');
+                    this.log(lines.pop());
                     throw new Error;
                 } else {
                     this.pos.push(ast.dpush(num));
@@ -47,10 +49,10 @@ function interpret (str, done) {
             } else {
                 num = parseInt(w, this.base);
                 if (Number.isNaN(num)) {
-                    lines = this.io.buf.slice(0, this.io.ptr).split('\n');
-                    console.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
-                    console.log('word: ' + w + ' is not defined');
-                    console.log(lines.pop());
+                    // lines = this.io.buf.slice(0, this.io.ptr).split('\n');
+                    // this.log('\n' + colors.red('Error:') + ' in line: ' + (lines.length - 1));
+                    // this.log('word: ' + w + ' is not defined');
+                    // this.log(lines.pop());
                     throw new Error;
                 } else {
                     this.dpush(num);
@@ -65,11 +67,23 @@ function main (cxt) {
         buf: 'nop',
         ptr: 0,
         last: 2,
-        parse: word.take,
-        word: word.str
+        parse: word.takeBuffer,
+        word: word.buf
     };
     cxt.state = 0; // 0 = interpret, 1 = compile
+    cxt.log = function (str) { cxt.s.push(new Buffer(str, 'ascii')); };
     cxt.interpret = interpret;
+    cxt.s.on('error', function (err) {
+        cxt.log('on error');
+        throw err;
+    });
+    cxt.s._write = function (chunk, enc, next) {
+        // cxt.log('_write');
+        cxt.interpret(chunk, next);
+    };
+    cxt.s._read = function (n) {
+        // cxt.log('_read');
+    };
 }
 
 module.exports = main;
